@@ -41,7 +41,8 @@ public:
         DayTodos,
         AllIncidences,
         AllEvents,
-        AllTodos
+        AllTodos,
+        OrganizerName
     };
 
     enum Roles {
@@ -72,7 +73,11 @@ public:
         Due,
         ValidStartDt,
         ValidEndDt,
-        ValidDueDt
+        ValidDueDt,
+        AttendeeEmails,
+        DisplayAttendeeEmails,
+        DisplaytAttendeeNames,
+        IncidenceStatus
     };
 
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
@@ -147,6 +152,8 @@ private:
     bool isHourEvent(const Event::Ptr event) const;
     bool withinFilter(const KCalendarCore::Event::Ptr event, const QDate &filterDate) const;
     void setCalendarFilter();
+    QStringList attendeeEmails(const int idx) const;
+    QStringList attendeeNames(const int idx) const;
 
     int m_filter_mode;
     QDate m_filter_dt;
